@@ -6,7 +6,7 @@ use base qw/Catalyst::Plugin::FormValidator/;
 use NEXT;
 require FormValidator::Simple;
 
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 
 sub setup {
     my $self = shift;
@@ -17,7 +17,11 @@ sub setup {
         : [];
         FormValidator::Simple->import(@$plugins);
     if ( $setting && exists $setting->{messages} ) {
-        FormValidator::Simple->set_messages( $setting->{messages} );
+        my $messages = $setting->{messages};
+        unless ( ref $messages && ref $messages eq 'HASH' ) {
+            $messages = $self->path_to( $messages )->stringify;
+        }
+        FormValidator::Simple->set_messages( $messages );
     }
     if ( $setting && exists $setting->{options} ) {
         FormValidator::Simple->set_option( %{ $setting->{options} } );
@@ -38,7 +42,7 @@ sub form {
     my $c = shift;
     if ($_[0]) {
         my $form = $_[1] ? [@_] : $_[0];
-        $c->{validator}->check($c->req->params, $form);
+        $c->{validator}->check($c->req, $form);
     }
     return $c->{validator}->results;
 }
